@@ -20,8 +20,9 @@ from calculate.lib.datavars import (Variable, ReadonlyVariable,
                                     ReadonlyTableVariable, FieldValue,
                                     HumanReadable)
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.lib.utils.files import readFile
+from calculate.lib.utils.files import readFile, readLinesFile
 from calculate.install.distr import DistributiveError
+import glob
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 
@@ -47,7 +48,7 @@ class VariableOsAudio(Variable):
         return {'none': ''}.get(value, value)
 
     def choice(self):
-        return  self.Get('os_audio_available') or [('',_('None'))]
+        return self.Get('os_audio_available') or [('', _('None'))]
 
 
 class VariableOsAudioAvailable(Variable):
@@ -58,20 +59,21 @@ class VariableOsAudioAvailable(Variable):
 
     def get(self):
         mapAudioConf = (('pulseaudio', 'media-sound/pulseaudio',
-                       _("PulseAudio")),
-                      ('alsa', 'media-sound/alsa-utils', _('ALSA')))
+                         _("PulseAudio")),
+                        ('alsa', 'media-sound/alsa-utils', _('ALSA')))
         image = self.Get('cl_image')
         if image:
             with image as distr:
                 try:
                     distrPath = image.getDirectory()
-                    return map(lambda x:x[0::2],
+                    return map(lambda x: x[0::2],
                                filter(lambda x: not x[1] or isPkgInstalled(x[1],
                                                                            prefix=distrPath),
                                       mapAudioConf))
                 except DistributiveError as e:
                     pass
-        return sorted(map(lambda x:x[0::2], mapNetConf[-1:]), key=lambda x:x[1])
+        return sorted(map(lambda x: x[0::2], mapAudioConf[-1:]),
+                      key=lambda x: x[1])
 
 
 class VariableOsAudioData(ReadonlyTableVariable):
@@ -81,11 +83,24 @@ class VariableOsAudioData(ReadonlyTableVariable):
     source = ['os_audio_id',
               'os_audio_name']
 
+    def generate_cards(self, cards):
+        for card_id, card_name in cards:
+            for playback_info in glob.glob(
+                            "/proc/asound/card%s/pcm[0-9]p/info" % card_id):
+                dInfo = (x.partition(":")[::2]
+                         for x in readLinesFile(playback_info))
+                dInfo = {x.strip(): y.strip() for x, y in dInfo}
+                if all(x in dInfo for x in ('card', 'device', 'name')):
+                    yield ("%s,%s" % (dInfo['card'], dInfo['device']),
+                           "%s, %s" % (card_name, dInfo['name']))
+
     def get(self, hr=HumanReadable.No):
+        # /proc/asound/card*/pcm*p/info
         data = readFile('/proc/asound/cards')
-        cards = re.findall('^\s*(\d+).*\n\s+(\S.*) at .*$', data, re.M)
+        cards = re.findall('^\s*(\d+).*\s-\s(.+)\n\s+\S.* at .*$',
+                           data, re.M)
         if cards:
-            return map(list, cards)
+            return list(self.generate_cards(cards))
         else:
             return [[]]
 
@@ -120,8 +135,8 @@ class VariableOsAudioDefaultSet(ReadonlyVariable):
         res = self.Select('os_audio_id', where='os_audio_name',
                           notlike='HDMI', limit=1)
         audio_default = self.Get('os_audio_default')
-        if (audio_default != '0' or
-                        res and res != "0" and audio_default == '0' or
+        if (audio_default != '0,0' or
+                        res and res != "0,0" and audio_default == '0,0' or
                     audio_default != self.Get('os_audio_current')):
             return 'on'
         return 'off'
@@ -133,13 +148,22 @@ class VariableOsAudioCurrent(ReadonlyVariable):
     """
 
     def get(self):
+        asound_data = readFile('/etc/asound.conf')
         default_card_re = re.compile('defaults.ctl.card\s+(\d+)')
-        entry = default_card_re.search(readFile('/etc/asound.conf'))
+        entry = default_card_re.search(asound_data)
         if entry and entry.groups()[0] in self.Get('os_audio_id'):
-            return entry.groups()[0]
+            return "%s,0" % entry.groups()[0]
+        default_card_re = re.compile(
+            'pcm.!default {[^}]+card\s+(\d+)[^}]+device\s+(\d+)[^}]+}')
+        entry = default_card_re.search(asound_data)
+        if entry:
+            entry = "%s,%s" % entry.groups()
+            if entry in self.Get('os_audio_id'):
+                return entry
+
         res = self.Select('os_audio_id', where='os_audio_name',
                           notlike='HDMI', limit=1)
-        return res or '0'
+        return res or '0,0'
 
 
 class VariableOsAudioDefault(Variable):
@@ -147,7 +171,7 @@ class VariableOsAudioDefault(Variable):
     Current default audio card
     """
     type = "choice"
-    opt = ['--audio-card']
+    opt = ['--card']
     metavalue = "CARD"
 
     def init(self):
@@ -170,6 +194,5 @@ class VariableOsAudioDefault(Variable):
         if self.Get('os_install_root_type') == 'flash':
             return _("Audio configuration unavailable for Flash install")
         if self.Get('os_install_alsa_set') == 'off':
-            return \
-                _("This distribution does not provide the ALSA sound")
+            return _("This distribution does not provide the ALSA sound")
         return ""
