@@ -324,7 +324,7 @@ class VariableClAutologin(UserHelper, Variable):
 
     def init(self):
         self.label = _("Autologin")
-        self.help = _("add an autologin user to the installed system, 'off' for disable autologin")
+        self.help = _("set an autologin for the user, 'off' for disable")
 
     def get(self):
         # autologin enable for livecd and all install type CMC
@@ -805,6 +805,14 @@ class VariableOsInstallX11ServerSet(PackageCheckVariable):
     package = "x11-base/xorg-server"
 
 
+class VariableOsInstallSplashSet(Variable):
+    """
+    Переменная отображать splash при загрузки
+    """
+    type = "bool"
+    value = "on"
+
+
 class FlashUncompatible(VariableInterface):
     def uncompatible(self):
         """
